@@ -6,9 +6,15 @@ use strict;
 
 sub run {
     my ($self,$pkgfile,$path)=@_;
-    if ( -e "Makefile" or -e 'makefile' ) {
+
+    my $makefile;
+    for(qw(Makefile makefile)) {
+        $makefile = $_ if -e $_ ;
+    }
+
+    if ( $makefile ) {
         $logger->info( "Makefile found. do make install.") ;
-        my $ret = system( "make install" );
+        my $ret = system( "make install -f $makefile" );
         return 1 if $ret == 0;
     }
 
